% script file GitterReg.m
% regularisation of a triangular mesh
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc; clear all; 


ndom = [10:5:120];
N = length(ndom);

iters.CG = zeros(N,1); iters.GMRES = zeros(N,1);
time.CG  = zeros(N,1); time.GMRES = zeros(N,1);

toler = 1e-6;
maxit = 5000;

for ctr = 1:N;
 n = ndom(ctr); % number of points along one boundary

 discretise_circle; % triangulation from Ex. 1, Blatt 6

 % now do the coordinate regularisation
 [A,RHSx,RHSy] = sysmat_GitterReg(N,n,TRI,Nodes);

 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 % CG method

 %x0 = 1*ones(size(RHSx));

 % better  guess for iv: old coordinates
 x0 = Nodes.x(1:N-n);

 K = A'*A; % symmetrise
 tic
 [NodesNewCG.x,Iters] = cg(K,A'*RHSx,x0,toler,maxit);
 t=toc;
 iters.CG(ctr) = Iters;
 time.CG(ctr) = t;

 
 clear NodesNewCG
 clear Iters
 % GMRES  
 tic
 [NodesNewGMRES.x,Iters] = Gmres(A,RHSx,toler,maxit,x0);  
 t=toc;
 iters.GMRES(ctr) = Iters; 
 time.GMRES(ctr) = t;
end


figure(1)
subplot(2,1,1)
plot(ndom,iters.CG,'r',ndom,iters.GMRES,'b');
legend('CG','GMRES')
title('Iterations');

subplot(2,1,2)
plot(ndom,time.CG,'r',ndom,time.GMRES,'b');
title('Runtime');


figure(2)
subplot(1,2,1)
loglog(ndom,iters.CG,'r',ndom,iters.GMRES,'b',ndom,ndom,'k',ndom,ndom.^2,'g');
legend('CG','GMRES','linear','quadratic')
title('Iterations');

subplot(1,2,2)
loglog(ndom,time.CG,'r',ndom,time.GMRES,'b',ndom,ndom,'k',ndom,ndom.^2,'g');
title('Runtime');



