% script file GitterRegGMRES.m
% regularisation of a triangular mesh
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clc; clear all; 


ndom = [10:5:120];
N = length(ndom);

iters.GMRES = zeros(N,1); iters.Restart = zeros(N,1);
time.GMRES  = zeros(N,1); time.Restart = zeros(N,1);

toler = 1e-6;
maxit = 5000;
maxit_outer = 500;
maxit_inner = 30;


for ctr = 1:N;
 n = ndom(ctr); % number of points along one boundary

 discretise_circle; % triangulation from Ex. 1, Blatt 6

 % now do the coordinate regularisation
 [A,RHSx,RHSy] = sysmat_GitterReg(N,n,TRI,Nodes);

 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

 x0 = 1*ones(size(RHSx));
 y0 = 1*ones(size(RHSx));

 % better  guess for iv: old coordinates
 %x0 = Nodes.x(1:N-n);
 %y0 = Nodes.y(1:N-n);

 % GMRES  
 tic
 [NodesNewGMRES.x,Iters] = Gmres(A,RHSx,toler,maxit,x0);  
 t=toc;
 iters.GMRES(ctr) = Iters; 
 time.GMRES(ctr) = t;
 
 
 tic
 [NodesNewGMRES.x,Iters] = GmresRestart(A,RHSx,toler,maxit_outer,maxit_inner,x0);  
 t=toc;
 iters.Restart(ctr) = Iters; 
 time.Restart(ctr) = t; 
 
end



figure(1)
subplot(2,1,1)
plot(ndom,iters.GMRES,'r',ndom,iters.Restart,'b');
legend('Full','restarted')
title('Iterations');

subplot(2,1,2)
plot(ndom,time.GMRES,'r',ndom,time.Restart,'b');
title('Runtime');


figure(2)
subplot(1,2,1)
loglog(ndom,iters.GMRES,'r',ndom,iters.Restart,'b');
legend('Full','Restarted')
title('Iterations');

subplot(1,2,2)
loglog(ndom,time.GMRES,'r',ndom,time.Restart,'b');
title('Runtime');



